@@ -100,14 +100,23 @@ def get_audio_text_data(i,
     json_data = create_key_value(json_data, 'audio_text', [])
     output_directory = if_none_get_def(if_not_dir_return_None(output_directory), os.getcwd())
     chunk_path = os.path.join(output_directory, f"chunk_{i}_partial.wav")
+    json_data = create_key_value(json_data,
+                     'chunk_length_ms',
+                     chunk_length_ms or 50000)
+    json_data = create_key_value(json_data,
+                     'chunk_length_diff',
+                     chunk_length_diff or -5)
+    json_data = create_key_value(json_data,
+                     'renew',
+                     renew or False)
     result = get_chunk_period(i,
                               audio_text=json_data['audio_text'],
-                              chunk_length_ms=chunk_length_ms,
-                              chunk_length_diff=chunk_length_diff,
+                              chunk_length_ms=json_data['chunk_length_ms'],
+                              chunk_length_diff=json_data['chunk_length_diff'],
                               audio_len=len(audio),
-                              renew=renew)
+                              renew=json_data['renew'])
     if isinstance(result, tuple):
-        logging.info(f"transcribing audio chunk {i}, start_time:{result[0]}, end_time:{result[1]}")
+        logger.info(f"transcribing audio chunk {i}, start_time:{result[0]}, end_time:{result[1]}")
         text = get_audio_text(start_time=result[0],
                               end_time=result[1],
                               audio=audio,
@@ -120,7 +129,7 @@ def get_audio_text_data(i,
         if file_path:
             safe_dump_to_file(json_data, file_path)
     else:
-        logging.info(f"audio text already transcribed for chunk {i}")
+        logger.info(f"audio text already transcribed for chunk {i}")
     if os.path.isfile(chunk_path):
         try:
             os.remove(chunk_path)
@@ -150,7 +159,7 @@ def get_audio_text_jsons(audio_path,
                                         file_path=file_path,
                                         renew=renew,
                                         output_directory=output_directory)
-        logging.info(f"chunk {i} of {len_chunks} processed")
+        logger.info(f"chunk {i} of {len_chunks} processed")
     return json_data
 
 def transcribe_audio_file(audio_path=None, json_data=None, video_path=None, chunk_length_ms=8000, chunk_length_diff=-5, renew=False):
@@ -169,11 +178,11 @@ def transcribe_audio_file(audio_path=None, json_data=None, video_path=None, chun
         return json_data
     if not audio_path and video_path:
         audio_path = os.path.join(os.path.dirname(video_path), 'audio.wav')
-        logging.info(f"audio path derived from video_path:{video_path}")
+        logger.info(f"audio path derived from video_path:{video_path}")
         json_data = create_key_value(json_data, 'audio_path', audio_path)
     if not os.path.isfile(audio_path) and video_path:
         extract_audio_from_video(video_path, audio_path)
-        logging.info(f"extracted audio from video:{audio_path}")
+        logger.info(f"extracted audio from video:{audio_path}")
     temp_file_path = file_path.replace('.json', '_temp.json')
     json_data = get_audio_text_jsons(audio_path=audio_path,
                                      json_data=json_data,
@@ -185,7 +194,7 @@ def transcribe_audio_file(audio_path=None, json_data=None, video_path=None, chun
     if os.path.isfile(temp_file_path):
         try:
             shutil.move(temp_file_path, file_path)
-            logging.info(f"temp_info_path transfered to info_path:{file_path}")
+            logger.info(f"temp_info_path transfered to info_path:{file_path}")
         except OSError as e:
             logger.error(f"Failed to move temp file to {file_path}: {e}")
     return json_data
@@ -198,10 +207,10 @@ def extract_audio_from_video(video_path, audio_path):
         video.close()
         if not os.path.exists(audio_path):
             raise FileNotFoundError(f"Audio file {audio_path} was not created.")
-        logging.info(f"Audio extracted successfully: {audio_path}")
+        logger.info(f"Audio extracted successfully: {audio_path}")
         return audio_path
     except Exception as e:
-        logging.error(f"Error extracting audio from {video_path}: {e}")
+        logger.error(f"Error extracting audio from {video_path}: {e}")
         return None
     
 def get_voice(voice, text=None):
