@@ -33,34 +33,23 @@ def is_frame_analyzed(frame_file,video_text_data):
         if frame_file == frame:
             return True
         
-def analyze_video_text(video_path=None,output_dir=None,json_data=None,remove_phrases=None):
-    json_data = json_data or {}
-    video_path = video_path or json_data.get('video_path')
+def analyze_video_text(video_path,output_dir,json_data,remove_phrases=None,video_id=None):
+    remove_phrases=remove_phrases or []
     if not video_path or not os.path.isfile(video_path):
         return json_data
     video = VideoFileClip(video_path)
-    thumbnails_directory = json_data.get('thumbnails_directory')
-    output_dir = output_dir or json_data.get('info_directory') or thumbnails_directory or os.path.dirname(video_path)
-    paths = glob.glob(path_join(output_dir, '**', 'thumbnails'), recursive=True)
-    if paths and len(paths)>0:
-        thumbnail_dir = paths[0]
-    json_data['thumbnails_directory']= thumbnails_directory or thumbnail_dir
     duration = video.duration
-    json_data = create_key_value(json_data,'remove_phrases',remove_phrases or [])
-    dirname = os.path.dirname(video_path)
-    basename = os.path.basename(video_path)
-    filename,ext = os.path.splitext(basename)
     frame_interval = 1  # Adjust as needed
     for t in range(0, int(duration), frame_interval):
-        frame_path = os.path.join(json_data['thumbnails_directory'],f"{filename}_frame_{t}.jpg")
+        frame_path = os.path.join(output_dir,f"{video_id}_frame_{t}.jpg")
         if not os.path.isfile(frame_path):
             frame = video.get_frame(t)
             cv2.imwrite(frame_path, cv2.cvtColor(np.array(frame), cv2.COLOR_RGB2BGR))
     json_data = create_key_value(json_data,'video_text',[])
-    for frame_file in os.listdir(thumbnails_directory):
+    for frame_file in os.listdir(output_dir):
         if frame_file.endswith(".jpg"):
             if not is_frame_analyzed(frame_file,json_data['video_text']):
-                image_path = os.path.join(thumbnails_directory,frame_file)
+                image_path = os.path.join(output_dir,frame_file)
                 raw_text = extract_text_from_image(image_path)
                 cleaned_text = clean_text(raw_text)
                 text = determine_remove_text(cleaned_text,remove_phrases=json_data['remove_phrases'])
