@@ -1,7 +1,5 @@
 #!/usr/bin/env python3
-from PIL import Image
-import argparse
-
+from .functions import argparse,Image
 def images_to_pdf(image_paths, output_pdf):
     if not image_paths:
         raise ValueError("No image files provided for conversion.")
