@@ -63,7 +63,7 @@ def get_seo_data(info,
                  uploader=None,
                  domain=None,
                  categories=None,
-                 video_url=None):
+                 videos_url=None):
     
     info = create_key_value(info,
                             'categories',
@@ -78,8 +78,8 @@ def get_seo_data(info,
                             domain or 'https://thedailydialectics.com')
     
     info = create_key_value(info,
-                            'video_url',
-                            video_url or url_join(info['domain'],'videos'))
+                            'videos_url',
+                            videos_url or f"{info['domain']}/videos")
     
     for keyword_key in ['combined_keywords','keywords']:
         keywords = info.get(keyword_key,[])
@@ -152,8 +152,8 @@ def get_seo_data(info,
     
     info['category'] = next((v for k, v in info['categories'].items() if k in ' '.join(info['seo_tags']).lower()), 'General')
     
-    info['uploader'] = {"name": uploader,
-                        "url": domain}
+    info['uploader'] = {"name": info['uploader'],
+                        "url": info['domain']}
     
     info['publication_date'] = get_time_now_iso()
     
