@@ -73,10 +73,11 @@ def transcribe_video_path(video_path,
                                  chunk_length_ms=chunk_length_ms,
                                  chunk_length_diff=chunk_length_diff,
                                  renew=renew)
-    info = analyze_video_text(video_path=video_path,
-                       output_dir=output_dir,
+    info = analyze_video_text(video_path=info['video_path'],
+                       output_dir=info['thumbnails_directory'],
                        json_data=info,
-                       remove_phrases=remove_phrases)
+                       remove_phrases=info['remove_phrases'],
+                              video_id=info['video_id'])
     
     info = get_text_and_keywords(info,
                                  summarizer=summarizer,
@@ -101,10 +102,11 @@ def get_info_data(video_path,
                   chunk_length_diff=None,
                   renew=None):
     remove_phrases = remove_phrases or []
-    
     basename = os.path.basename(video_path)
     filename, ext = os.path.splitext(basename)
-    info_directory = make_dirs(output_dir, filename)
+    video_id = filename.replace(' ', '-').lower()
+    info_directory = make_dirs(output_dir, video_id)
+    thumbnails_directory = make_dirs(info_directory, 'thumbnails')
     info_path = os.path.join(info_directory, 'info.json')
     video_text_path = os.path.join(info_directory, 'video_text.json')
     audio_path = os.path.join(info_directory, 'audio.wav')
@@ -113,9 +115,8 @@ def get_info_data(video_path,
     uploader = uploader or 'The Daily Dialectics'
     domain = domain or 'https://thedailydialectics.com'
     videos_url = videos_url or f"{domain}/videos"
-    video_id = info['filename'].replace(' ', '-').lower()
     canonical_url = f"{videos_url}/{video_id}"
-    chunk_length_ms = if_none_get_def(chunk_length_ms, 50000)
+    chunk_length_ms = if_none_get_def(chunk_length_ms, 1000)
     chunk_length_diff = if_none_get_def(chunk_length_diff, -5)
     renew = if_none_get_def(renew, False)
     info = {}
@@ -124,6 +125,7 @@ def get_info_data(video_path,
     info['parent_dir']=output_dir
     info['video_path'] = video_path
     info['info_directory'] = info_directory
+    info['thumbnails_directory']=thumbnails_directory
     info['info_path'] = info_path
     info['filename'] = filename
     info['ext'] = ext
